@@ -57,17 +57,11 @@ func parse(args []string) error {
 		return err
 	}
 
+	//nolint:staticcheck
 	enhancedAST, err := rp.PrepareAST(filename, content, module)
 	if err != nil {
 		return err
 	}
 
-	output, err := encoding.JSON().MarshalIndent(enhancedAST, "", "  ")
-	if err != nil {
-		return err
-	}
-
-	_, err = os.Stdout.Write(output)
-
-	return err
+	return encoding.NewIndentEncoder(os.Stdout, "", "  ").Encode(enhancedAST)
 }
