@@ -145,6 +145,7 @@ func TestLintV0WithRegoV1ImportViolations(t *testing.T) {
 	regal("lint",
 		"--format", "json",
 		"--config-file", cwd("testdata/configs/v0-with-import-rego-v1.yaml"), cwd("testdata/v0/")).
+		skip(onCondition(runtime.GOOS == "windows", "skipping on Windows")).
 		expectExitCode(3).
 		expectStdout(unmarshalsTo(&rep)).
 		verify(t)
@@ -449,7 +450,7 @@ test_allow if {
 		"v0/main.rego": `package v0
 
 #comment
-allow { true }
+allow { input == 1 }
 `,
 		"v1/main.rego": `package v1
 
@@ -460,22 +461,25 @@ allow if { true }
 	}
 
 	td := testutil.TempDirectoryOf(t, initialState)
-	exp := fmt.Sprintf(`12 fixes applied:
+	exp := fmt.Sprintf(`16 fixes applied:
 In project root: %[1]s
 bar/main.rego -> wow/foo-bar/baz/main.rego:
 - directory-package-mismatch
 
 bar/main_test.rego -> wow/foo-bar/baz/main_test.rego:
 - directory-package-mismatch
+- constant-condition
 - opa-fmt
 
 foo/main.rego -> wow/main.rego:
 - directory-package-mismatch
+- constant-condition
 - no-whitespace-comment
 - opa-fmt
 
 foo/main_test.rego -> wow/main_test.rego:
 - directory-package-mismatch
+- constant-condition
 - opa-fmt
 
 
@@ -486,6 +490,7 @@ main.rego:
 
 In project root: %[3]s
 main.rego:
+- constant-condition
 - no-whitespace-comment
 - opa-fmt
 `, td, filepath.Join(td, "v0"), filepath.Join(td, "v1"))
@@ -503,29 +508,29 @@ allow if {
 `,
 		filepath.FromSlash("wow/foo-bar/baz/main_test.rego"): `package wow["foo-bar"].baz_test
 
-test_allow := true
+test_allow if {}
 `,
 		"wow/main.rego": `package wow
 
 # comment
 
-allow := true
+allow if {}
 `,
 		"wow/main_test.rego": `package wow_test
 
-test_allow := true
+test_allow if {}
 `,
 		"v0/main.rego": `package v0
 
 import rego.v1
 
 # comment
-allow := true
+allow if input == 1
 `,
 		"v1/main.rego": `package v1
 
 # comment
-allow := true
+allow if {}
 `,
 		"unrelated.txt": `foobar`,
 	}
