@@ -7,12 +7,14 @@ import (
 	"slices"
 
 	"github.com/open-policy-agent/opa/v1/bundle"
+
+	rio "github.com/open-policy-agent/regal/internal/io"
 )
 
 // LoadDataBundle loads a bundle from the given path but only includes data
 // files. The path must contain a bundle manifest file.
 func LoadDataBundle(path string) (bundle.Bundle, error) {
-	if _, err := os.Stat(filepath.Join(path, ".manifest")); err != nil {
+	if !rio.IsFile(filepath.Join(path, ".manifest")) {
 		return bundle.Bundle{}, fmt.Errorf("manifest file was not found at bundle path %q", path)
 	}
 
@@ -25,11 +27,6 @@ func LoadDataBundle(path string) (bundle.Bundle, error) {
 }
 
 func dataFileLoaderFilter(abspath string, info os.FileInfo, _ int) bool {
-	if info.IsDir() {
-		return false
-	}
-
-	basename := filepath.Base(abspath)
-
-	return !slices.Contains([]string{".manifest", "data.json", "data.yml", "data.yaml"}, basename)
+	return !info.IsDir() &&
+		!slices.Contains([]string{".manifest", "data.json", "data.yml", "data.yaml"}, filepath.Base(abspath))
 }
