@@ -6,8 +6,9 @@ import (
 
 	"github.com/open-policy-agent/opa/v1/ast"
 
-	"github.com/styrainc/regal/internal/lsp/types"
-	"github.com/styrainc/regal/pkg/report"
+	"github.com/open-policy-agent/regal/internal/lsp/types"
+	"github.com/open-policy-agent/regal/internal/testutil"
+	"github.com/open-policy-agent/regal/pkg/report"
 )
 
 func TestManageAggregates(t *testing.T) {
@@ -127,36 +128,21 @@ func TestManageAggregates(t *testing.T) {
 func TestPartialDiagnosticsUpdate(t *testing.T) {
 	t.Parallel()
 
-	c := NewCache()
-
 	diag1 := types.Diagnostic{Code: "code1"}
 	diag2 := types.Diagnostic{Code: "code2"}
 	diag3 := types.Diagnostic{Code: "code3"}
 
-	c.SetFileDiagnostics("foo.rego", []types.Diagnostic{
-		diag1, diag2,
-	})
-
-	foundDiags, ok := c.GetFileDiagnostics("foo.rego")
-	if !ok {
-		t.Fatalf("expected to get diags for foo.rego")
-	}
+	c := NewCache()
+	c.SetFileDiagnostics("foo.rego", []types.Diagnostic{diag1, diag2})
 
+	foundDiags := testutil.MustBeOK(c.GetFileDiagnostics("foo.rego"))(t)
 	if !reflect.DeepEqual(foundDiags, []types.Diagnostic{diag1, diag2}) {
 		t.Fatalf("unexpected diagnostics: %v", foundDiags)
 	}
 
-	c.SetFileDiagnosticsForRules(
-		"foo.rego",
-		[]string{"code2", "code3"},
-		[]types.Diagnostic{diag3},
-	)
-
-	foundDiags, ok = c.GetFileDiagnostics("foo.rego")
-	if !ok {
-		t.Fatalf("expected to get diags for foo.rego")
-	}
+	c.SetFileDiagnosticsForRules("foo.rego", []string{"code2", "code3"}, []types.Diagnostic{diag3})
 
+	foundDiags = testutil.MustBeOK(c.GetFileDiagnostics("foo.rego"))(t)
 	if !reflect.DeepEqual(foundDiags, []types.Diagnostic{diag1, diag3}) {
 		t.Fatalf("unexpected diagnostics: %v", foundDiags)
 	}
@@ -166,23 +152,15 @@ func TestCacheRename(t *testing.T) {
 	t.Parallel()
 
 	c := NewCache()
-
 	c.SetFileContents("file:///tmp/foo.rego", "package foo")
 	c.SetModule("file:///tmp/foo.rego", &ast.Module{})
-
 	c.Rename("file:///tmp/foo.rego", "file:///tmp/bar.rego")
 
-	_, ok := c.GetFileContents("file:///tmp/foo.rego")
-	if ok {
+	if _, ok := c.GetFileContents("file:///tmp/foo.rego"); ok {
 		t.Fatalf("expected foo.rego to be removed")
 	}
 
-	contents, ok := c.GetFileContents("file:///tmp/bar.rego")
-	if !ok {
-		t.Fatalf("expected bar.rego to be present")
-	}
-
-	if contents != "package foo" {
+	if contents := testutil.MustBeOK(c.GetFileContents("file:///tmp/bar.rego"))(t); contents != "package foo" {
 		t.Fatalf("unexpected contents: %s", contents)
 	}
 }
