@@ -5,12 +5,12 @@ import (
 
 	"github.com/sourcegraph/jsonrpc2"
 
-	"github.com/styrainc/roast/pkg/encoding"
+	"github.com/open-policy-agent/regal/pkg/roast/encoding"
 )
 
-type handlerFunc[T any] func(T) (any, error)
+type Func[T any] func(T) (any, error)
 
-type handlerContextFunc[T any] func(context.Context, T) (any, error)
+type ContextFunc[T any] func(context.Context, T) (any, error)
 
 var ErrInvalidParams = &jsonrpc2.Error{Code: jsonrpc2.CodeInvalidParams}
 
@@ -26,7 +26,7 @@ func Decode[T any](req *jsonrpc2.Request, params *T) error {
 	return nil
 }
 
-func WithParams[T any](req *jsonrpc2.Request, h handlerFunc[T]) (any, error) {
+func WithParams[T any](req *jsonrpc2.Request, h Func[T]) (any, error) {
 	var params T
 	if err := Decode(req, &params); err != nil {
 		return nil, err
@@ -35,7 +35,7 @@ func WithParams[T any](req *jsonrpc2.Request, h handlerFunc[T]) (any, error) {
 	return h(params)
 }
 
-func WithContextAndParams[T any](ctx context.Context, req *jsonrpc2.Request, h handlerContextFunc[T]) (any, error) {
+func WithContextAndParams[T any](ctx context.Context, req *jsonrpc2.Request, h ContextFunc[T]) (any, error) {
 	var params T
 	if err := Decode(req, &params); err != nil {
 		return nil, err
