@@ -49,6 +49,7 @@ import (
 	"github.com/open-policy-agent/regal/internal/util"
 	"github.com/open-policy-agent/regal/internal/web"
 	"github.com/open-policy-agent/regal/pkg/config"
+	"github.com/open-policy-agent/regal/pkg/config/modify"
 	"github.com/open-policy-agent/regal/pkg/fixer"
 	"github.com/open-policy-agent/regal/pkg/fixer/fileprovider"
 	"github.com/open-policy-agent/regal/pkg/fixer/fixes"
@@ -82,11 +83,12 @@ var (
 	regalEvalUseAsInputComment = regexp.MustCompile(`^\s*regal eval:\s*use-as-input`)
 	validPathComponentPattern  = regexp.MustCompile(`^\w+[\w\-]*\w+$`)
 
-	fixFmt                   = &fixes.Fmt{OPAFmtOpts: format.Opts{}}
-	fixUseRegoV1             = &fixes.Fmt{OPAFmtOpts: format.Opts{RegoVersion: ast.RegoV0CompatV1}}
-	fixUseAssignmentOperator = &fixes.UseAssignmentOperator{}
-	fixNoWhitespaceComment   = &fixes.NoWhitespaceComment{}
-	fixNonRawRegexPattern    = &fixes.NonRawRegexPattern{}
+	fixFmt                    = &fixes.Fmt{OPAFmtOpts: format.Opts{}}
+	fixUseRegoV1              = &fixes.Fmt{OPAFmtOpts: format.Opts{RegoVersion: ast.RegoV0CompatV1}}
+	fixUseAssignmentOperator  = &fixes.UseAssignmentOperator{}
+	fixNoWhitespaceComment    = &fixes.NoWhitespaceComment{}
+	fixNonRawRegexPattern     = &fixes.NonRawRegexPattern{}
+	fixPreferEqualsComparison = &fixes.PreferEqualsComparison{}
 )
 
 type LanguageServerOptions struct {
@@ -346,7 +348,7 @@ func (l *LanguageServer) StartDiagnosticsWorker(ctx context.Context) {
 				l.sendFileDiagnostics(ctx, job.URI)
 
 				l.lintWorkspaceJobs <- lintWorkspaceJob{
-					Reason: fmt.Sprintf("file %s %s", job.URI, job.Reason),
+					Reason: "file " + job.URI + " " + job.Reason,
 					// this run is expected to used the cached aggregate state
 					// for other files.
 					// The aggregate state for this file will still be updated.
@@ -550,7 +552,7 @@ func (l *LanguageServer) StartConfigWorker(ctx context.Context) {
 	}
 }
 
-func (l *LanguageServer) StartCommandWorker(ctx context.Context) { //nolint:maintidx
+func (l *LanguageServer) StartCommandWorker(ctx context.Context) {
 	// note, in this function conn.Call is used as the workspace/applyEdit message is a request, not a notification
 	// as per the spec. In order to be 'routed' to the correct handler on the client it must have an ID
 	// receive responses too.
@@ -597,6 +599,8 @@ func (l *LanguageServer) StartCommandWorker(ctx context.Context) { //nolint:main
 				fixed, editParams, err = l.fixEditParams("Format comment to have leading whitespace", fixNoWhitespaceComment, args)
 			case "regal.fix.non-raw-regex-pattern":
 				fixed, editParams, err = l.fixEditParams("Replace \" with ` in regex pattern", fixNonRawRegexPattern, args)
+			case "regal.fix.prefer-equals-comparison":
+				fixed, editParams, err = l.fixEditParams("Replace = with == in comparison", fixPreferEqualsComparison, args)
 			case "regal.fix.directory-package-mismatch":
 				params, err := l.fixRenameParams("Rename file to match package path", args.Target)
 				if err != nil {
@@ -611,6 +615,8 @@ func (l *LanguageServer) StartCommandWorker(ctx context.Context) { //nolint:main
 
 				// handle this ourselves as it's a rename and not a content edit
 				fixed = false
+			case "regal.eval":
+				err = l.handleEvalCommand(ctx, args)
 			case "regal.debug":
 				if args.Target == "" || args.Query == "" {
 					l.log.Message("expected command target and query, got target %q, query %q", args.Target, args.Query)
@@ -634,112 +640,14 @@ func (l *LanguageServer) StartCommandWorker(ctx context.Context) { //nolint:main
 				if err = l.conn.Call(ctx, "regal/startDebugging", responseParams, &responseResult); err != nil {
 					l.log.Message("regal/startDebugging failed: %s", err.Error())
 				}
-			case "regal.eval":
-				if args.Target == "" || args.Query == "" {
-					l.log.Message("expected command target and query, got target %q, query %q", args.Target, args.Query)
-
-					break
-				}
-
-				contents, module, ok := l.cache.GetContentAndModule(args.Target)
-				if !ok {
-					l.log.Message("failed to get content or module for file %q", args.Target)
-
-					break
-				}
-
-				var pq *query.Prepared
-
-				pq, err = l.queryCache.GetOrSet(ctx, l.regoStore, query.RuleHeadLocations)
+			case "regal.config.disable-rule":
+				err = l.handleIgnoreRuleCommand(ctx, args)
 				if err != nil {
-					l.log.Message("failed to prepare query %s", query.RuleHeadLocations, err)
-
-					break
+					l.log.Message("failed to ignore rule: %s", err)
 				}
 
-				var allRuleHeadLocations rego.RuleHeads
-
-				allRuleHeadLocations, err = rego.AllRuleHeadLocations(
-					ctx, pq, filepath.Base(uri.ToPath(args.Target)), contents, module,
-				)
-				if err != nil {
-					l.log.Message("failed to get rule head locations: %s", err)
-
-					break
-				}
-
-				// if there are none, then it's a package evaluation
-				ruleHeadLocations := allRuleHeadLocations[args.Query]
-
-				var inputMap map[string]any
-
-				// When the first comment in the file is `regal eval: use-as-input`, the AST of that module is
-				// used as the input rather than the contents of input.json/yaml. This is a development feature for
-				// working on rules (built-in or custom), allowing querying the AST of the module directly.
-				if len(module.Comments) > 0 && regalEvalUseAsInputComment.Match(module.Comments[0].Text) {
-					inputMap, err = rparse.PrepareAST(l.toRelativePath(args.Target), contents, module)
-					if err != nil {
-						l.log.Message("failed to prepare module: %s", err)
-
-						break
-					}
-				} else {
-					// Normal mode — try to find the input.json/yaml file in the workspace and use as input
-					// NOTE that we don't break on missing input, as some rules don't depend on that, and should
-					// still be evaluable. We may consider returning some notice to the user though.
-					_, inputMap = rio.FindInput(uri.ToPath(args.Target), l.workspacePath())
-				}
-
-				var result EvalResult
-
-				if result, err = l.EvalInWorkspace(ctx, args.Query, inputMap); err != nil {
-					fmt.Fprintf(os.Stderr, "failed to evaluate workspace path: %v\n", err)
-
-					break
-				}
-
-				target := "package"
-				if len(ruleHeadLocations) > 0 {
-					target = strings.TrimPrefix(args.Query, module.Package.Path.String()+".")
-				}
-
-				if l.client.InitOptions.EvalCodelensDisplayInline != nil &&
-					*l.client.InitOptions.EvalCodelensDisplayInline {
-					responseParams := map[string]any{
-						"result": result,
-						"line":   args.Row,
-						"target": target,
-						// only used when the target is 'package'
-						"package": strings.TrimPrefix(module.Package.Path.String(), "data."),
-						// only used when the target is a rule
-						"rule_head_locations": ruleHeadLocations,
-					}
-
-					responseResult := map[string]any{}
-
-					if err = l.conn.Call(ctx, "regal/showEvalResult", responseParams, &responseResult); err != nil {
-						l.log.Message("regal/showEvalResult failed: %v", err.Error())
-					}
-				} else {
-					output := filepath.Join(l.workspacePath(), "output.json")
-
-					var f *os.File
-
-					f, err = os.OpenFile(output, os.O_CREATE|os.O_TRUNC|os.O_WRONLY, 0o755)
-					if err == nil {
-						value := result.Value
-						if result.IsUndefined {
-							value = emptyStringAnyMap // undefined displays as an empty object
-						}
-
-						var jsonVal []byte
-						if jsonVal, err = encoding.JSON().MarshalIndent(value, "", "  "); err == nil {
-							_, err = f.Write(jsonVal)
-						}
-
-						rio.CloseIgnore(f)
-					}
-				}
+				// handle this ourselves as it's a config edit
+				fixed = false
 			}
 
 			if err != nil {
@@ -1096,7 +1004,7 @@ func (l *LanguageServer) templateContentsForFile(fileURI string) (string, error)
 
 		switch {
 		case strings.Contains(part, "-"):
-			pkg += fmt.Sprintf(`["%s"]`, part)
+			pkg += fmt.Sprintf("[%q]", part)
 		case pkg == "":
 			pkg += part
 		default:
@@ -1256,6 +1164,59 @@ func (l *LanguageServer) fixRenameParams(label, fileURI string) (types.ApplyWork
 	return types.ApplyWorkspaceAnyEditParams{Label: label, Edit: types.WorkspaceAnyEdit{DocumentChanges: changes}}, nil
 }
 
+func (l *LanguageServer) handleIgnoreRuleCommand(_ context.Context, args types.CommandArgs) error {
+	if args.Diagnostic == nil {
+		return errors.New("diagnostic is required to ignore rule")
+	}
+
+	ruleCode := args.Diagnostic.Code
+	category := strings.TrimPrefix(*args.Diagnostic.Source, "regal/")
+
+	// find or create config file
+	var configPath string
+
+	if configFile, err := config.Find(l.workspacePath()); err == nil {
+		defer configFile.Close()
+
+		configPath = configFile.Name()
+	} else {
+		regalDir := filepath.Join(l.workspacePath(), ".regal")
+		if err := os.MkdirAll(regalDir, 0o755); err != nil {
+			return fmt.Errorf("failed to create .regal directory: %w", err)
+		}
+
+		configPath = filepath.Join(regalDir, "config.yaml")
+	}
+
+	var currentContent string
+
+	content, err := os.ReadFile(configPath)
+	if err == nil {
+		currentContent = string(content)
+	}
+
+	// default to empty set of rules
+	if strings.TrimSpace(currentContent) == "" {
+		currentContent = "rules: {}\n"
+	}
+
+	path := []string{"rules", category, ruleCode, "level"}
+
+	newContent, err := modify.SetKey(currentContent, path, "ignore")
+	if err != nil {
+		return fmt.Errorf("failed to modify config: %w", err)
+	}
+
+	// TODO: we need to trigger a config reload so that the server starts using
+	// the new config immediately. Currently, the server will pick up the config
+	// change through file system watchers only.
+	if err := os.WriteFile(configPath, []byte(newContent), 0o600); err != nil {
+		return fmt.Errorf("failed to write config file: %w", err)
+	}
+
+	return nil
+}
+
 // processHoverContentUpdate updates information about built in, and keyword
 // positions in the cache for use when handling hover requests.
 func (l *LanguageServer) processHoverContentUpdate(ctx context.Context, fileURI string) error {
@@ -1932,6 +1893,8 @@ func (l *LanguageServer) handleInitialize(ctx context.Context, params types.Init
 					"regal.fix.no-whitespace-comment",
 					"regal.fix.directory-package-mismatch",
 					"regal.fix.non-raw-regex-pattern",
+					"regal.fix.prefer-equals-comparison",
+					"regal.config.disable-rule",
 				},
 			},
 			DocumentFormattingProvider: true,
@@ -2287,6 +2250,110 @@ func (l *LanguageServer) regalContext(fileURI string, req *rego.Requirements) re
 	return rctx
 }
 
+func (l *LanguageServer) handleEvalCommand(ctx context.Context, args types.CommandArgs) error {
+	if args.Target == "" || args.Query == "" {
+		l.log.Message("expected command target and query, got target %q, query %q", args.Target, args.Query)
+
+		return nil
+	}
+
+	contents, module, ok := l.cache.GetContentAndModule(args.Target)
+	if !ok {
+		l.log.Message("failed to get content or module for file %q", args.Target)
+
+		return nil
+	}
+
+	var pq *query.Prepared
+
+	pq, err := l.queryCache.GetOrSet(ctx, l.regoStore, query.RuleHeadLocations)
+	if err != nil {
+		l.log.Message("failed to prepare query %s", query.RuleHeadLocations, err)
+
+		return nil
+	}
+
+	var allRuleHeadLocations rego.RuleHeads
+
+	allRuleHeadLocations, err = rego.AllRuleHeadLocations(
+		ctx, pq, filepath.Base(uri.ToPath(args.Target)), contents, module,
+	)
+	if err != nil {
+		l.log.Message("failed to get rule head locations: %s", err)
+
+		return nil
+	}
+
+	// if there are none, then it's a package evaluation
+	ruleHeadLocations := allRuleHeadLocations[args.Query]
+
+	var inputMap map[string]any
+
+	// When the first comment in the file is `regal eval: use-as-input`, the AST of that module is
+	// used as the input rather than the contents of input.json/yaml. This is a development feature for
+	// working on rules (built-in or custom), allowing querying the AST of the module directly.
+	if len(module.Comments) > 0 && regalEvalUseAsInputComment.Match(module.Comments[0].Text) {
+		//nolint:staticcheck
+		inputMap, err = rparse.PrepareAST(l.toRelativePath(args.Target), contents, module)
+		if err != nil {
+			l.log.Message("failed to prepare module: %s", err)
+
+			return nil
+		}
+	} else {
+		// Normal mode — try to find the input.json/yaml file in the workspace and use as input
+		// NOTE that we don't break on missing input, as some rules don't depend on that, and should
+		// still be evaluable. We may consider returning some notice to the user though.
+		_, inputMap = rio.FindInput(uri.ToPath(args.Target), l.workspacePath())
+	}
+
+	var result EvalResult
+
+	if result, err = l.EvalInWorkspace(ctx, args.Query, inputMap); err != nil {
+		return fmt.Errorf("failed to evaluate workspace path: %w", err)
+	}
+
+	target := "package"
+	if len(ruleHeadLocations) > 0 {
+		target = strings.TrimPrefix(args.Query, module.Package.Path.String()+".")
+	}
+
+	if l.client.InitOptions.EvalCodelensDisplayInline != nil &&
+		*l.client.InitOptions.EvalCodelensDisplayInline {
+		responseParams := map[string]any{
+			"result": result,
+			"line":   args.Row,
+			"target": target,
+			// only used when the target is 'package'
+			"package": strings.TrimPrefix(module.Package.Path.String(), "data."),
+			// only used when the target is a rule
+			"rule_head_locations": ruleHeadLocations,
+		}
+
+		responseResult := map[string]any{}
+
+		if err = l.conn.Call(ctx, "regal/showEvalResult", responseParams, &responseResult); err != nil {
+			l.log.Message("regal/showEvalResult failed: %v", err.Error())
+		}
+	} else {
+		output := filepath.Join(l.workspacePath(), "output.json")
+
+		var f *os.File
+		if f, err = os.OpenFile(output, os.O_CREATE|os.O_TRUNC|os.O_WRONLY, 0o755); err == nil {
+			value := result.Value
+			if result.IsUndefined {
+				value = emptyStringAnyMap // undefined displays as an empty object
+			}
+
+			err = encoding.NewIndentEncoder(f, "", "  ").Encode(value)
+
+			rio.CloseIgnore(f)
+		}
+	}
+
+	return err
+}
+
 func positionToOffset(text string, p types.Position) int {
 	bytesRead := 0
 
