@@ -10,9 +10,12 @@ import (
 
 	"github.com/sourcegraph/jsonrpc2"
 
+	"github.com/open-policy-agent/regal/internal/lsp/clients"
 	"github.com/open-policy-agent/regal/internal/lsp/log"
 	"github.com/open-policy-agent/regal/internal/lsp/types"
+	"github.com/open-policy-agent/regal/internal/lsp/uri"
 	"github.com/open-policy-agent/regal/internal/testutil"
+	"github.com/open-policy-agent/regal/internal/util"
 	"github.com/open-policy-agent/regal/pkg/report"
 )
 
@@ -66,7 +69,7 @@ import rego.v1
 		}
 	}
 
-	barURI := fileURIScheme + filepath.Join(tempDir, "bar.rego")
+	barURI := uri.FromPath(clients.IdentifierGoTest, filepath.Join(tempDir, "bar.rego"))
 
 	if err := connClient.Notify(ctx, "textDocument/didChange", types.DidChangeTextDocumentParams{
 		TextDocument: types.TextDocumentIdentifier{
@@ -102,7 +105,7 @@ import rego.v1
 		}
 	}
 
-	fooURI := fileURIScheme + filepath.Join(tempDir, "foo.rego")
+	fooURI := uri.FromPath(clients.IdentifierGoTest, filepath.Join(tempDir, "foo.rego"))
 
 	if err := connClient.Notify(ctx, "textDocument/didChange", types.DidChangeTextDocumentParams{
 		TextDocument: types.TextDocumentIdentifier{
@@ -259,39 +262,35 @@ import data.quz
 			if aggregateData, ok := entry["aggregate_data"].(map[string]any); ok {
 				if importsList, ok := aggregateData["imports"].([]any); ok {
 					for _, imp := range importsList {
-						if item, ok := imp.([]any); ok {
-							if pathList, ok := item[0].([]any); ok {
-								pathParts := []string{}
+						item := testutil.MustBe[[]any](t, imp)
+						if pathList, ok := item[0].([]any); ok {
+							pathParts := []string{}
 
-								for _, p := range pathList {
-									if pathStr, ok := p.(string); ok {
-										pathParts = append(pathParts, pathStr)
-									}
+							for _, p := range pathList {
+								if pathStr, ok := p.(string); ok {
+									pathParts = append(pathParts, pathStr)
 								}
-
-								imports = append(imports, strings.Join(pathParts, "."))
 							}
+
+							imports = append(imports, strings.Join(pathParts, "."))
 						}
 					}
 				}
 			}
 		}
 
-		slices.Sort(imports)
-
-		return imports
+		return util.Sorted(imports)
 	}
 
 	imports := determineImports(ls.cache.GetFileAggregates())
-
-	if exp, got := []string{"baz", "quz"}, imports; !slices.Equal(exp, got) {
-		t.Fatalf("global state imports unexpected, got %v exp %v", got, exp)
+	if exp := []string{"baz", "quz"}; !slices.Equal(exp, imports) {
+		t.Fatalf("global state imports unexpected, got %v exp %v", imports, exp)
 	}
 
 	// 2. check the aggregates for a file are updated after an update
 	if err := connClient.Notify(ctx, "textDocument/didChange", types.DidChangeTextDocumentParams{
 		TextDocument: types.TextDocumentIdentifier{
-			URI: fileURIScheme + filepath.Join(tempDir, "bar.rego"),
+			URI: uri.FromPath(clients.IdentifierGoTest, filepath.Join(tempDir, "bar.rego")),
 		},
 		ContentChanges: []types.TextDocumentContentChangeEvent{
 			{
@@ -386,7 +385,7 @@ import rego.v1
 	}
 
 	// update the contents of the bar.rego file to address the unresolved-import
-	barURI := fileURIScheme + filepath.Join(tempDir, "bar.rego")
+	barURI := uri.FromPath(clients.IdentifierGoTest, filepath.Join(tempDir, "bar.rego"))
 
 	err = connClient.Notify(ctx, "textDocument/didChange", types.DidChangeTextDocumentParams{
 		TextDocument: types.TextDocumentIdentifier{
