@@ -3,21 +3,18 @@ package lsp
 import (
 	"testing"
 
-	"github.com/styrainc/regal/internal/lsp/log"
+	"github.com/open-policy-agent/regal/internal/lsp/log"
+	"github.com/open-policy-agent/regal/pkg/config"
 )
 
-// https://github.com/StyraInc/regal/issues/679
+// https://github.com/open-policy-agent/regal/issues/679
 func TestProcessBuiltinUpdateExitsOnMissingFile(t *testing.T) {
 	t.Parallel()
 
-	logger := newTestLogger(t)
+	ls := NewLanguageServer(t.Context(), &LanguageServerOptions{Logger: log.NewLogger(log.LevelDebug, t.Output())})
+	ls.loadedConfig = &config.Config{}
 
-	ls := NewLanguageServer(
-		t.Context(),
-		&LanguageServerOptions{LogWriter: logger, LogLevel: log.LevelDebug},
-	)
-
-	if err := ls.processHoverContentUpdate(t.Context(), "file://missing.rego", "foo"); err != nil {
+	if err := ls.processHoverContentUpdate(t.Context(), "file://missing.rego"); err != nil {
 		t.Fatal(err)
 	}
 
@@ -25,8 +22,7 @@ func TestProcessBuiltinUpdateExitsOnMissingFile(t *testing.T) {
 		t.Errorf("expected builtin positions to be empty, got %d items", l)
 	}
 
-	contents, ok := ls.cache.GetFileContents("file://missing.rego")
-	if ok {
+	if contents, ok := ls.cache.GetFileContents("file://missing.rego"); ok {
 		t.Errorf("expected file contents to be empty, got %s", contents)
 	}
 
