@@ -7,7 +7,7 @@ import (
 
 	"github.com/open-policy-agent/opa/v1/ast"
 
-	"github.com/open-policy-agent/regal/internal/roast/encoding/util"
+	"github.com/open-policy-agent/regal/internal/roast/encoding/write"
 )
 
 type importCodec struct{}
@@ -19,15 +19,15 @@ func (*importCodec) IsEmpty(_ unsafe.Pointer) bool {
 func (*importCodec) Encode(ptr unsafe.Pointer, stream *jsoniter.Stream) {
 	imp := *((*ast.Import)(ptr))
 
-	util.ObjectStart(stream, imp.Location)
+	write.ObjectStart(stream, imp.Location)
 
 	if imp.Path != nil {
-		util.WriteVal(stream, strPath, imp.Path)
+		write.Val(stream, strPath, imp.Path)
 
 		if imp.Alias != "" {
-			util.WriteVal(stream, strAlias, imp.Alias)
+			write.Val(stream, strAlias, imp.Alias)
 		}
 	}
 
-	util.ObjectEnd(stream)
+	write.ObjectEnd(stream)
 }
