@@ -7,7 +7,7 @@ import (
 
 	"github.com/open-policy-agent/opa/v1/ast"
 
-	"github.com/open-policy-agent/regal/internal/roast/encoding/util"
+	"github.com/open-policy-agent/regal/internal/roast/encoding/write"
 )
 
 type withCodec struct{}
@@ -19,8 +19,8 @@ func (*withCodec) IsEmpty(_ unsafe.Pointer) bool {
 func (*withCodec) Encode(ptr unsafe.Pointer, stream *jsoniter.Stream) {
 	with := *((*ast.With)(ptr))
 
-	util.ObjectStart(stream, with.Location)
-	util.WriteVal(stream, strTarget, with.Target)
-	util.WriteVal(stream, strValue, with.Value)
-	util.ObjectEnd(stream)
+	write.ObjectStart(stream, with.Location)
+	write.Val(stream, strTarget, with.Target)
+	write.Val(stream, strValue, with.Value)
+	write.ObjectEnd(stream)
 }
