@@ -201,6 +201,7 @@ func findUpwards(path, name string, expectDir bool) (string, error) {
 			return searchPath, nil
 		}
 
+		//nolint:gocritic
 		if searchPath == volume+string(os.PathSeparator)+name {
 			return "", errors.New("can't traverse past root directory")
 		}
@@ -366,12 +367,12 @@ func AllRegoVersions(root string, conf *Config) (map[string]ast.RegoVersion, err
 	}
 
 	for _, dir := range manifestLocations {
-		f, err := os.ReadFile(filepath.Join(root, dir, ".manifest"))
+		b, err := os.ReadFile(filepath.Join(root, dir, ".manifest"))
 		if err != nil {
 			return nil, fmt.Errorf("failed to read manifest file: %w", err)
 		}
 
-		manifest, err := encoding.JSONUnmarshalTo[bundle.Manifest](f)
+		manifest, err := encoding.JSONUnmarshalTo[bundle.Manifest](b)
 		if err != nil {
 			return nil, fmt.Errorf("failed to unmarshal manifest file: %w", err)
 		}
@@ -699,7 +700,7 @@ func extractDefaults(c *Config, result *marshallingIntermediary) error {
 
 // CapabilitiesForThisVersion returns the capabilities for the current OPA version Regal depends on.
 func CapabilitiesForThisVersion() *Capabilities {
-	return fromOPACapabilities(rio.OPACapabilities)
+	return fromOPACapabilities(rio.OPACapabilities())
 }
 
 func fromOPABuiltin(builtin ast.Builtin) *Builtin {
