@@ -5,7 +5,7 @@ import (
 
 	"github.com/open-policy-agent/opa/v1/ast"
 
-	"github.com/styrainc/regal/pkg/rules"
+	"github.com/open-policy-agent/regal/pkg/rules"
 )
 
 type FileProvider interface {
@@ -16,7 +16,7 @@ type FileProvider interface {
 	Delete(string) error
 	Rename(string, string) error
 
-	ToInput(versionsMap map[string]ast.RegoVersion) (rules.Input, error)
+	ToInput(map[string]ast.RegoVersion) (rules.Input, error)
 }
 
 type RenameConflictError struct {
