@@ -10,9 +10,9 @@ import (
 	"path/filepath"
 	"slices"
 	"strings"
-	"sync"
 	"testing/fstest"
 
+	"golang.org/x/sync/errgroup"
 	"gopkg.in/yaml.v3"
 
 	"github.com/open-policy-agent/opa/v1/ast"
@@ -26,14 +26,16 @@ import (
 	outil "github.com/open-policy-agent/opa/v1/util"
 
 	rbundle "github.com/open-policy-agent/regal/bundle"
+	"github.com/open-policy-agent/regal/internal/exp"
 	rio "github.com/open-policy-agent/regal/internal/io"
 	regalmetrics "github.com/open-policy-agent/regal/internal/metrics"
 	"github.com/open-policy-agent/regal/internal/util"
-	"github.com/open-policy-agent/regal/pkg/builtins"
 	"github.com/open-policy-agent/regal/pkg/config"
 	"github.com/open-policy-agent/regal/pkg/report"
 	"github.com/open-policy-agent/regal/pkg/roast/transform"
 	"github.com/open-policy-agent/regal/pkg/rules"
+
+	_ "github.com/open-policy-agent/regal/pkg/builtins"
 )
 
 // Linter stores data to use for linting.
@@ -374,12 +376,7 @@ func (l Linter) Lint(ctx context.Context) (report.Report, error) {
 	if l.inputModules != nil {
 		l.startTimer(regalmetrics.RegalFilterIgnoredModules)
 
-		filteredPaths, err := config.FilterIgnoredPaths(
-			l.inputModules.FileNames,
-			ignore,
-			false,
-			l.pathPrefix,
-		)
+		filteredPaths, err := config.FilterIgnoredPaths(l.inputModules.FileNames, ignore, false, l.pathPrefix)
 		if err != nil {
 			return report.Report{}, fmt.Errorf("failed to filter paths: %w", err)
 		}
@@ -393,6 +390,10 @@ func (l Linter) Lint(ctx context.Context) (report.Report, error) {
 		l.stopTimer(regalmetrics.RegalFilterIgnoredModules)
 	}
 
+	if len(l.inputPaths) == 0 && l.inputModules == nil && len(l.overriddenAggregates) == 0 {
+		return report.Report{}, errors.New("nothing provided to lint")
+	}
+
 	regoReport, err := l.lint(ctx, input)
 	if err != nil {
 		return report.Report{}, fmt.Errorf("failed to lint using Rego rules: %w", err)
@@ -536,10 +537,6 @@ func (l Linter) notPrepared() Linter {
 }
 
 func (l Linter) validate(conf *config.Config) error {
-	if len(l.inputPaths) == 0 && l.inputModules == nil && len(l.overriddenAggregates) == 0 {
-		return errors.New("nothing provided to lint")
-	}
-
 	if l.customRuleError != nil {
 		return fmt.Errorf("failed to load custom rules: %w", l.customRuleError)
 	}
@@ -651,6 +648,11 @@ func (l Linter) createDataBundle(conf config.Config) *bundle.Bundle {
 		"ignore_files":     util.NilSliceToEmpty(l.ignoreFiles),
 	}
 
+	userConfigMap := map[string]any{}
+	if l.userConfig != nil {
+		userConfigMap = config.ToMap(*l.userConfig)
+	}
+
 	return &bundle.Bundle{
 		Manifest: bundle.Manifest{
 			Roots:    &[]string{"internal", "eval"},
@@ -662,6 +664,7 @@ func (l Linter) createDataBundle(conf config.Config) *bundle.Bundle {
 			},
 			"internal": map[string]any{
 				"combined_config": config.ToMap(conf),
+				"user_config":     userConfigMap,
 				"capabilities":    rio.ToMap(config.CapabilitiesForThisVersion()),
 				"path_prefix":     l.pathPrefix,
 			},
@@ -674,12 +677,12 @@ func (l Linter) prepareRegoArgs(query ast.Body) ([]func(*rego.Rego), error) {
 		return nil, fmt.Errorf("failed to load custom rules: %w", l.customRuleError)
 	}
 
-	regoArgs := append([]func(*rego.Rego){
+	regoArgs := []func(*rego.Rego){
 		rego.StoreReadAST(true),
 		rego.Metrics(l.metrics),
 		rego.ParsedQuery(query),
 		rego.Instrument(l.instrumentation),
-	}, builtins.RegalBuiltinRegoFuncs...)
+	}
 
 	if l.debugMode && l.printHook == nil {
 		l.printHook = topdown.NewPrintHook(os.Stderr)
@@ -721,30 +724,24 @@ func (l Linter) lint(ctx context.Context, input rules.Input) (report.Report, err
 	numFiles := len(input.FileNames)
 	operationCollect := numFiles > 1 || l.useCollectQuery
 
-	var wg sync.WaitGroup
-
-	// the error channel is buffered to prevent blocking
-	// caused by the context cancellation happening before
-	// errors are sent and the per-file goroutines can exit.
-	errCh := make(chan error, numFiles)
-	doneCh := make(chan bool)
+	// NB(sr): We benchmarked using `wg.SetLimit(runtime.GOMAXPROCS(-1))` here, but performance
+	// got a little worse. So let's not bother.
+	wg, ctx := errgroup.WithContext(ctx)
 
 	results := make([]report.Report, numFiles)
 
 	for i, name := range input.FileNames {
-		wg.Add(1)
-
-		go func(name string) {
-			defer wg.Done()
-
+		wg.Go(func() error {
 			inputValue, err := transform.ToAST(name, input.FileContent[name], input.Modules[name], operationCollect)
 			if err != nil {
-				errCh <- fmt.Errorf("failed to transform input value: %w", err)
-
-				return
+				return fmt.Errorf("failed to transform input value: %w", err)
 			}
 
-			evalArgs := []rego.EvalOption{rego.EvalParsedInput(inputValue), rego.EvalInstrument(l.instrumentation)}
+			evalArgs := []rego.EvalOption{
+				rego.EvalParsedInput(inputValue),
+				rego.EvalInstrument(l.instrumentation),
+				exp.ExternalCancelNoOp,
+			}
 
 			if l.baseCache != nil {
 				evalArgs = append(evalArgs, rego.EvalBaseCache(l.baseCache))
@@ -762,16 +759,12 @@ func (l Linter) lint(ctx context.Context, input rules.Input) (report.Report, err
 
 			resultSet, err := l.preparedQuery.Eval(ctx, evalArgs...)
 			if err != nil {
-				errCh <- fmt.Errorf("error encountered in query evaluation %w", err)
-
-				return
+				return fmt.Errorf("error encountered in query evaluation %w", err)
 			}
 
 			result, err := report.FromResultSet(resultSet, false)
 			if err != nil {
-				errCh <- fmt.Errorf("failed to convert result set to report: %w", err)
-
-				return
+				return fmt.Errorf("failed to convert result set to report: %w", err)
 			}
 
 			if l.profiling {
@@ -787,61 +780,58 @@ func (l Linter) lint(ctx context.Context, input rules.Input) (report.Report, err
 			}
 
 			results[i] = result
-		}(name)
+
+			return nil
+		})
 	}
 
-	go func() {
-		wg.Wait()
-
-		doneCh <- true
-	}()
-
-	select {
-	case <-ctx.Done():
-		return report.Report{}, fmt.Errorf("context cancelled: %w", ctx.Err())
-	case err := <-errCh:
-		return report.Report{}, fmt.Errorf("error encountered in rule evaluation %w", err)
-	case <-doneCh:
-		l.startTimer(regalmetrics.RegalMergeReport)
-		defer l.stopTimer(regalmetrics.RegalMergeReport)
-
-		regoReport := report.Report{
-			Aggregates:       make(map[string][]report.Aggregate, numFiles),
-			IgnoreDirectives: make(map[string]map[string][]string, numFiles),
+	if err := wg.Wait(); err != nil {
+		if errors.Is(err, context.Canceled) {
+			return report.Report{}, fmt.Errorf("context cancelled: %w", err)
 		}
 
-		for i := range results {
-			regoReport.Violations = append(regoReport.Violations, results[i].Violations...)
-			regoReport.Notices = append(regoReport.Notices, results[i].Notices...)
+		return report.Report{}, fmt.Errorf("error encountered in rule evaluation %w", err)
+	}
 
-			for k := range results[i].Aggregates {
-				// Custom aggregate rules that have been invoked but not returned any data
-				// will return an empty map to signal that they have been called, and that
-				// the aggregate report for this rule should be invoked even when no data
-				// was aggregated. This because the absence of data is exactly what some rules
-				// will want to report on.
-				for _, agg := range results[i].Aggregates[k] {
-					if len(agg) == 0 {
-						if _, ok := regoReport.Aggregates[k]; !ok {
-							regoReport.Aggregates[k] = make([]report.Aggregate, 0)
-						}
-					} else {
-						regoReport.Aggregates[k] = append(regoReport.Aggregates[k], agg)
+	l.startTimer(regalmetrics.RegalMergeReport)
+	defer l.stopTimer(regalmetrics.RegalMergeReport)
+
+	regoReport := report.Report{
+		Aggregates:       make(map[string][]report.Aggregate, numFiles),
+		IgnoreDirectives: make(map[string]map[string][]string, numFiles),
+	}
+
+	for i := range results {
+		regoReport.Violations = append(regoReport.Violations, results[i].Violations...)
+		regoReport.Notices = append(regoReport.Notices, results[i].Notices...)
+
+		for k := range results[i].Aggregates {
+			// Custom aggregate rules that have been invoked but not returned any data
+			// will return an empty map to signal that they have been called, and that
+			// the aggregate report for this rule should be invoked even when no data
+			// was aggregated. This because the absence of data is exactly what some rules
+			// will want to report on.
+			for _, agg := range results[i].Aggregates[k] {
+				if len(agg) == 0 {
+					if _, ok := regoReport.Aggregates[k]; !ok {
+						regoReport.Aggregates[k] = make([]report.Aggregate, 0)
 					}
+				} else {
+					regoReport.Aggregates[k] = append(regoReport.Aggregates[k], agg)
 				}
 			}
-
-			for k := range results[i].IgnoreDirectives {
-				regoReport.IgnoreDirectives[k] = results[i].IgnoreDirectives[k]
-			}
-
-			if l.profiling {
-				regoReport.AddProfileEntries(results[i].AggregateProfile)
-			}
 		}
 
-		return regoReport, nil
+		for k := range results[i].IgnoreDirectives {
+			regoReport.IgnoreDirectives[k] = results[i].IgnoreDirectives[k]
+		}
+
+		if l.profiling {
+			regoReport.AddProfileEntries(results[i].AggregateProfile)
+		}
 	}
+
+	return regoReport, nil
 }
 
 func (l Linter) lintWithAggregateRules(
@@ -875,6 +865,7 @@ func (l Linter) lintWithAggregateRules(
 	evalArgs := []rego.EvalOption{
 		rego.EvalParsedInput(inputValue),
 		rego.EvalInstrument(l.instrumentation),
+		exp.ExternalCancelNoOp,
 	}
 
 	if l.metrics != nil {
