@@ -30,7 +30,6 @@ type Location struct {
 	File   string    `json:"file"`
 	Column int       `json:"col"`
 	Row    int       `json:"row"`
-	Offset int       `json:"offset,omitempty"`
 }
 
 // Violation describes any violation found by Regal.
@@ -144,7 +143,7 @@ func (a Aggregate) IndexKey() string {
 		return ""
 	}
 
-	return fmt.Sprintf("%s/%s", cat, title)
+	return cat + "/" + title
 }
 
 func (r *Report) AddProfileEntries(prof map[string]ProfileEntry) {
