@@ -1,6 +1,7 @@
 package encoding
 
 import (
+	"io"
 	"log"
 
 	jsoniter "github.com/json-iterator/go"
@@ -36,7 +37,7 @@ func JSONUnmarshalTo[T any](bs []byte) (to T, err error) {
 }
 
 // JSONRoundTrip convert any value to JSON and back again.
-func JSONRoundTrip(from any, to any) error {
+func JSONRoundTrip(from, to any) error {
 	bs, err := jsoniter.ConfigFastest.Marshal(from)
 	if err != nil {
 		return err
@@ -57,7 +58,7 @@ func JSONRoundTripTo[T any](from any) (to T, err error) {
 }
 
 // MustJSONRoundTrip convert any value to JSON and back again, exit on failure.
-func MustJSONRoundTrip(from any, to any) {
+func MustJSONRoundTrip(from, to any) {
 	if err := JSONRoundTrip(from, to); err != nil {
 		log.Fatal(err)
 	}
@@ -72,3 +73,11 @@ func MustJSONRoundTripTo[T any](from any) T {
 
 	return to
 }
+
+// NewIndentEncoder creates a new JSON encoder with the specified prefix and indent, encoding to w.
+func NewIndentEncoder(w io.Writer, prefix, indent string) *jsoniter.Encoder {
+	enc := JSON().NewEncoder(w)
+	enc.SetIndent(prefix, indent)
+
+	return enc
+}
